Module response

Module response 

Modules

sse
Server-Sent Events (SSE) responses.

Structs

AppendHeaders
Append headers to a response.
ErrorResponse
An IntoResponse-based error type
Extension
Extractor and response for extensions.
Form
URL encoded extractor and response.
Html
An HTML response.
HttpResponse
Json
JSON Extractor / Response.
Redirect
Response that redirects the request to another location.
ResponseParts
Parts of a response.
Sse
An SSE response
TypedHeader
Extractor and response that works with typed header values from headers.

Traits

IntoResponse
Trait for generating responses.
IntoResponseParts
Trait for adding headers and extensions to a response.

Type Aliases

Response
Type alias for http::Response whose body type defaults to BoxBody, the most common body type used with axum.
Result
An IntoResponse-based result type that uses ErrorResponse as the error type.