Re-exports
pub use response::Json;pub use response::TypedHeader;pub use response::Form;pub use response::Extension;
Modules
- sse
- Server-Sent Events (SSE) responses.
Structs
- Append
Headers - Append headers to a response.
- Error
Response - An
IntoResponse-based error type - Html
- An HTML response.
- Http
Response - Redirect
- Response that redirects the request to another location.
- Response
Parts - Parts of a response.
- Sse
- An SSE response
Traits
- Into
Response - Trait for generating responses.
- Into
Response Parts - Trait for adding headers and extensions to a response.
Type Aliases
- Response
- Type alias for
http::Responsewhose body type defaults toBoxBody, the most common body type used with axum. - Result
- An
IntoResponse-based result type that usesErrorResponseas the error type.