Modules
- future
- Future types.
Structs
- AddExtension
- Middleware for adding some shareable value to request extensions.
- From
Extractor - Middleware that runs an extractor and discards the value.
- From
Extractor Layer Layerthat appliesFromExtractorthat runs an extractor and discards the value.- FromFn
- A middleware created from an async function.
- From
FnLayer - A
tower::Layerfrom an async function. - MapRequest
- A middleware created from an async function that transforms a request.
- MapRequest
Layer - A
tower::Layerfrom an async function that transforms a request. - MapResponse
- A middleware created from an async function that transforms a response.
- MapResponse
Layer - A
tower::Layerfrom an async function that transforms a response. - Next
- The remainder of a middleware stack, including the handler.
Traits
- Into
MapRequest Result - Trait implemented by types that can be returned from
map_request,map_request_with_state.
Functions
- from_
extractor - Create a middleware from an extractor.
- from_
extractor_ with_ state - Create a middleware from an extractor with the given state.
- from_fn
- Create a middleware from an async function.
- from_
fn_ with_ state - Create a middleware from an async function with the given state.
- map_
request - Create a middleware from an async function that transforms a request.
- map_
request_ with_ state - Create a middleware from an async function that transforms a request, with the given state.
- map_
response - Create a middleware from an async function that transforms a response.
- map_
response_ with_ state - Create a middleware from an async function that transforms a response, with the given state.